// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Hitran download options QML component (used to specify how the HITRAN database is to be accessed: 0 - segmented download as new regions are requested and saving for later reuse, 1 - complete download (auto or manual) once and save for offline use, 2 - download every time (no saving of downloaded data))
import QtQuick 2.7
import QtQuick.Controls 2.0
import QtQuick.Layouts 1.0
import QtQuick.Window 2.2

Item {

    id: hitranDownloadOptionsItem
    anchors.fill: parent

    Component.onCompleted:
    {
        if (hitranDownloadOptionsDataObj.hitranFileUsage === 0)
        {
            option1SegmentedDownloadAndStoreCheckBox.checked = true
            option2CompleteDownloadAndStoreCheckBox.checked = false
            option3DownloadEveryTimeCheckBox.checked = false
        }
        else if (hitranDownloadOptionsDataObj.hitranFileUsage === 1)
        {
            option1SegmentedDownloadAndStoreCheckBox.checked = false
            option2CompleteDownloadAndStoreCheckBox.checked = true
            option3DownloadEveryTimeCheckBox.checked = false
        }
        else if (hitranDownloadOptionsDataObj.hitranFileUsage == 2)
        {
            option1SegmentedDownloadAndStoreCheckBox.checked = false
            option2CompleteDownloadAndStoreCheckBox.checked = false
            option3DownloadEveryTimeCheckBox.checked = true
        }
    }

    // Rectangle to shade the background
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: 'black'
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        id: formRect
        anchors.fill: hitranDownloadOptionsColumnLayout
        anchors.margins: coreObj.defaultLabelHeight * (-0.85)
        color: "white"
        border.width: 1
        border.color: 'gray'
        radius: coreObj.defaultLabelHeight * 0.5
    }

    // Exit button
    CustomButton {
        id: exitButton
        anchors.top: hitranDownloadOptionsItem.top
        anchors.right: hitranDownloadOptionsItem.right
        anchors.margins: coreObj.defaultLabelHeight * (0.1)
        implicitWidth: 1.5 * exitButton.height
        text: qsTr("X")
        onClicked: hitranDownloadOptionsItem.destroy()
    }

    // Column layout to hold all the interface items
    ColumnLayout {        
        id: hitranDownloadOptionsColumnLayout
        anchors.centerIn: parent
        Layout.fillWidth: true
        Layout.fillHeight: true
        spacing: 5        
        CustomLabel {
            id: commentLabel
            Layout.fillWidth: true            
            text: qsTr("HITRANonline spectral database access modes")
        }
        Rectangle {
            id: separatorRect
            Layout.fillWidth: true
            height: 1            
            color: '#C0C0C0'
        }
        CustomCheckBox {
            id: option1SegmentedDownloadAndStoreCheckBox
            padding: 0
            onCheckedChanged: {
                if (checked)
                {
                    option1SegmentedDownloadAndStoreCheckBox.checked = true
                    option2CompleteDownloadAndStoreCheckBox.checked = false
                    option3DownloadEveryTimeCheckBox.checked = false
                    hitranDownloadOptionsDataObj.hitranFileUsage = 0;
                    separator2Rect.visible = false
                    detailsLabel.visible = false
                    downloadHitranButton.visible = false
                    separator2Rect.enabled = false
                    detailsLabel.enabled = false
                    downloadHitranButton.enabled = false
                }
            }
            onClicked: option1SegmentedDownloadAndStoreCheckBox.checked = true
            text: (Qt.platform.os == 'ios') ? qsTr("Segmented download as new regions\nare requested and saving for later reuse") : qsTr("   Segmented download as new regions\n   are requested and saving for later reuse")
        }

        CustomCheckBox {
            id: option2CompleteDownloadAndStoreCheckBox
            padding: 0
            onCheckedChanged: {
                if (checked)
                {
                    option1SegmentedDownloadAndStoreCheckBox.checked = false
                    option2CompleteDownloadAndStoreCheckBox.checked = true
                    option3DownloadEveryTimeCheckBox.checked = false
                    hitranDownloadOptionsDataObj.hitranFileUsage = 1;

                    if (hitranDownloadOptionsDataObj.cumulativeHitranExists === false)
                    {
                        separator2Rect.visible = true
                        detailsLabel.visible = true
                        downloadHitranButton.visible = true
                        separator2Rect.enabled = true
                        detailsLabel.enabled = true
                        downloadHitranButton.enabled = true
                        formRect.radius = formRect.height * 0.02
                    }
                    else
                    {
                        separator2Rect.visible = true
                        detailsLabel.visible = true
                        separator2Rect.enabled = true
                        detailsLabel.enabled = true
                        downloadHitranButton.visible = false
                        downloadHitranButton.enabled = false
                        formRect.radius = formRect.height * 0.02
                    }
                }
            }
            onClicked: option2CompleteDownloadAndStoreCheckBox.checked = true
            text: (Qt.platform.os == 'ios') ? qsTr("Complete download once (auto or\nmanual) and offline reuse later") : qsTr("   Complete download once (auto or\n   manual) and offline reuse later")
        }

        CustomCheckBox {
            id: option3DownloadEveryTimeCheckBox
            padding: 0
            onCheckedChanged: {
                if (checked)
                {
                    option1SegmentedDownloadAndStoreCheckBox.checked = false
                    option2CompleteDownloadAndStoreCheckBox.checked = false
                    option3DownloadEveryTimeCheckBox.checked = true
                    hitranDownloadOptionsDataObj.hitranFileUsage = 2;

                    separator2Rect.visible = false
                    detailsLabel.visible = false
                    downloadHitranButton.visible = false
                    separator2Rect.enabled = false
                    detailsLabel.enabled = false
                    downloadHitranButton.enabled = false
                }
            }
            onClicked: option3DownloadEveryTimeCheckBox.checked = true
            text: (Qt.platform.os === 'ios') ? qsTr("Download every time\n(no saving of downloaded data ever)") : qsTr("   Download every time\n   (no saving of downloaded data ever)")
        }

        Rectangle {
            id: separator2Rect
            Layout.fillWidth: true
            height: 1            
            color: '#D3D3D3'
        }

        CustomLabel {
            // anchors.fill: parent
            id: detailsLabel
            text: {
                if (coreObj.externalStorageAccessGranted)
                {
                    if (hitranDownloadOptionsDataObj.cumulativeHitranExists) { return qsTr("The complete HITRAN database is present\nunder 'Documents/bytran'.") }
                                                                        else { return qsTr("Offline mode requires the complete HITRAN\ndatabase to be present (~700 megabytes). \nIt may be downloaded or manually placed\ninto the 'Downloads/bytran' folder.") }
                }
                else
                {
                    if (hitranDownloadOptionsDataObj.cumulativeHitranExists) {
                        if (Qt.platform.os === 'android') { return qsTr("The complete HITRAN database is present but\nwas placed in the hidden app folder because\nno external storage read/write permission has\nbeen granted.") }
                                                     else { return qsTr("The complete HITRAN database is present\nand stored in a hidden app folder due to the\noperating system restrictions.") }
                    }
                    else { return qsTr("Offline mode requires the complete HITRAN\ndatabase to be present (~700 megabytes).\nIt may be downloaded from hitran.org.") }
                }
            }
        }

        // Such conditional implementation was introduced to make sure the fonts look properly both under desktop as well as the mobile platforms
        // Need to test this more thoroughly under mobile platforms, not sure all platforms will result in descent looks
        CustomButtonWithBackground {
            id: downloadHitranButton
            Layout.fillWidth: true            
            text: qsTr("Download HITRAN")

            // Enabling the closing of the form when the exit button is pressed
            onClicked: {
                hitranDownloadOptionsDataObj.downloadCompleteHitran();
                var component = Qt.createComponent("Notifier.qml")
                if (component.status === Component.Ready)
                {
                    downloadNotifierWindow = component.createObject(hitranDownloadOptionsItem)
                }
                else
                {
                    messageDialog.show(component.errorString())
                }
                downloadNotifierWindow.show()
            }
        }
    }
}
