// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | contact@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The following resource has been consulted to convert the relative humidity to ppmv and vise versa
// https://en.wikipedia.org/wiki/Arden_Buck_equation
// and
// http://dx.doi.org/10.1175/1520-0450(1981)020%3C1527:NEFCVP%3E2.0.CO;2
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object is used to convert from humidity to ppmv and vise versa
#ifndef HUMIDITYCONVERT_H
#define HUMIDITYCONVERT_H


class HumidityConvert
{
public:
    HumidityConvert();

    // From and to relative humidity (to/from ppmv respectively)
    double fromRelativeHumidityToPpmv(double rh, double tempC, double totalPressPa);
    double fromPpmvToRelativeHumidity(double ppmv, double tempC, double totalPressPa);

private:

    // Saturation water pressure in kPa for temperatures above freezing (> 0 Celsius)
    double getPaWaterSaturationPressAboveFreezing(double tempC);
    // Saturation water pressure in kPa for temperatures above freezing (< 0 Celsius)
    double getPaWaterSaturationPressBelowFreezing(double tempC);

};

#endif // HUMIDITYCONVERT_H
